@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Optional, Sequence, Tuple, List, Union
+from typing import List, Optional, Sequence, Tuple, Union
 
 import torch
 import torch.nn.functional as F
@@ -20,10 +20,10 @@ from pytorch_lightning.utilities import rank_zero_warn
 
 
 def _binary_clf_curve(
-        preds: torch.Tensor,
-        target: torch.Tensor,
-        sample_weights: Optional[Sequence] = None,
-        pos_label: int = 1.,
+    preds: torch.Tensor,
+    target: torch.Tensor,
+    sample_weights: Optional[Sequence] = None,
+    pos_label: int = 1.,
 ) -> Tuple[torch.Tensor, torch.Tensor, torch.Tensor]:
     """
     adapted from https://github.com/scikit-learn/scikit-learn/blob/master/sklearn/metrics/_ranking.py
@@ -63,19 +63,15 @@ def _binary_clf_curve(
 
 
 def _precision_recall_curve_update(
-        preds: torch.Tensor,
-        target: torch.Tensor,
-        num_classes: Optional[int] = None,
-        pos_label: Optional[int] = None,
+    preds: torch.Tensor,
+    target: torch.Tensor,
+    num_classes: Optional[int] = None,
+    pos_label: Optional[int] = None,
 ) -> Tuple[torch.Tensor, torch.Tensor, int, int]:
     if not (len(preds.shape) == len(target.shape) or len(preds.shape) == len(target.shape) + 1):
-        raise ValueError(
-            "preds and target must have same number of dimensions, or one additional dimension for preds"
-        )
+        raise ValueError("preds and target must have same number of dimensions, or one additional dimension for preds")
     # single class evaluation
     if len(preds.shape) == len(target.shape):
-        if num_classes is not None and num_classes != 1:
-            raise ValueError('Preds and target have equal shape, but number of classes is different from 1')
         num_classes = 1
         if pos_label is None:
             rank_zero_warn('`pos_label` automatically set 1.')
@@ -86,12 +82,16 @@ def _precision_recall_curve_update(
     # multi class evaluation
     if len(preds.shape) == len(target.shape) + 1:
         if pos_label is not None:
-            rank_zero_warn('Argument `pos_label` should be `None` when running'
-                           f'multiclass precision recall curve. Got {pos_label}')
+            rank_zero_warn(
+                'Argument `pos_label` should be `None` when running'
+                f' multiclass precision recall curve. Got {pos_label}'
+            )
         if num_classes != preds.shape[1]:
-            raise ValueError(f'Argument `num_classes` was set to {num_classes} in'
-                             f'metric `precision_recall_curve` but detected {preds.shape[1]}'
-                             'number of classes from predictions')
+            raise ValueError(
+                f'Argument `num_classes` was set to {num_classes} in'
+                f' metric `precision_recall_curve` but detected {preds.shape[1]}'
+                ' number of classes from predictions'
+            )
         preds = preds.transpose(0, 1).reshape(num_classes, -1).transpose(0, 1)
         target = target.flatten()
 
@@ -99,20 +99,17 @@ def _precision_recall_curve_update(
 
 
 def _precision_recall_curve_compute(
-        preds: torch.Tensor,
-        target: torch.Tensor,
-        num_classes: int,
-        pos_label: int,
-        sample_weights: Optional[Sequence] = None,
-) -> Union[Tuple[torch.Tensor, torch.Tensor, torch.Tensor],
-           Tuple[List[torch.Tensor], List[torch.Tensor], List[torch.Tensor]]]:
+    preds: torch.Tensor,
+    target: torch.Tensor,
+    num_classes: int,
+    pos_label: int,
+    sample_weights: Optional[Sequence] = None,
+) -> Union[Tuple[torch.Tensor, torch.Tensor, torch.Tensor], Tuple[List[torch.Tensor], List[torch.Tensor],
+                                                                  List[torch.Tensor]]]:
 
     if num_classes == 1:
         fps, tps, thresholds = _binary_clf_curve(
-            preds=preds,
-            target=target,
-            sample_weights=sample_weights,
-            pos_label=pos_label
+            preds=preds, target=target, sample_weights=sample_weights, pos_label=pos_label
         )
 
         precision = tps / (tps + fps)
@@ -125,13 +122,9 @@ def _precision_recall_curve_compute(
 
         # need to call reversed explicitly, since including that to slice would
         # introduce negative strides that are not yet supported in pytorch
-        precision = torch.cat([reversed(precision[sl]),
-                               torch.ones(1, dtype=precision.dtype,
-                                          device=precision.device)])
+        precision = torch.cat([reversed(precision[sl]), torch.ones(1, dtype=precision.dtype, device=precision.device)])
 
-        recall = torch.cat([reversed(recall[sl]),
-                            torch.zeros(1, dtype=recall.dtype,
-                                        device=recall.device)])
+        recall = torch.cat([reversed(recall[sl]), torch.zeros(1, dtype=recall.dtype, device=recall.device)])
 
         thresholds = reversed(thresholds[sl]).clone()
 
@@ -156,24 +149,26 @@ def _precision_recall_curve_compute(
 
 
 def precision_recall_curve(
-        preds: torch.Tensor,
-        target: torch.Tensor,
-        num_classes: Optional[int] = None,
-        pos_label: Optional[int] = None,
-        sample_weights: Optional[Sequence] = None,
-) -> Union[Tuple[torch.Tensor, torch.Tensor, torch.Tensor],
-           Tuple[List[torch.Tensor], List[torch.Tensor], List[torch.Tensor]]]:
+    preds: torch.Tensor,
+    target: torch.Tensor,
+    num_classes: Optional[int] = None,
+    pos_label: Optional[int] = None,
+    sample_weights: Optional[Sequence] = None,
+) -> Union[Tuple[torch.Tensor, torch.Tensor, torch.Tensor], Tuple[List[torch.Tensor], List[torch.Tensor],
+                                                                  List[torch.Tensor]]]:
     """
     Computes precision-recall pairs for different thresholds.
 
     Args:
+        preds: predictions from model (probabilities)
+        target: ground truth labels
         num_classes: integer with number of classes. Not nessesary to provide
             for binary problems.
         pos_label: integer determining the positive class. Default is ``None``
             which for binary problem is translate to 1. For multiclass problems
             this argument should not be set as we iteratively change it in the
             range [0,num_classes-1]
-        sample_weight: sample weights for each data point
+        sample_weights: sample weights for each data point
 
     Returns: 3-element tuple containing
 
@@ -208,14 +203,14 @@ def precision_recall_curve(
         ...                      [0.05, 0.05, 0.05, 0.75, 0.05]])
         >>> target = torch.tensor([0, 1, 3, 2])
         >>> precision, recall, thresholds = precision_recall_curve(pred, target, num_classes=5)
-        >>> precision
-        [tensor([1., 1.]), tensor([1., 1.]), tensor([0.2500, 0.0000, 1.0000]), tensor([0.2500, 0.0000, 1.0000]), tensor([0., 1.])]
+        >>> precision   # doctest: +NORMALIZE_WHITESPACE
+        [tensor([1., 1.]), tensor([1., 1.]), tensor([0.2500, 0.0000, 1.0000]),
+         tensor([0.2500, 0.0000, 1.0000]), tensor([0., 1.])]
         >>> recall
         [tensor([1., 0.]), tensor([1., 0.]), tensor([1., 0., 0.]), tensor([1., 0., 0.]), tensor([nan, 0.])]
         >>> thresholds
         [tensor([0.7500]), tensor([0.7500]), tensor([0.0500, 0.7500]), tensor([0.0500, 0.7500]), tensor([0.0500])]
 
     """
-    preds, target, num_classes, pos_label = _precision_recall_curve_update(preds, target,
-                                                                           num_classes, pos_label)
+    preds, target, num_classes, pos_label = _precision_recall_curve_update(preds, target, num_classes, pos_label)
     return _precision_recall_curve_compute(preds, target, num_classes, pos_label, sample_weights)
